@@ -175,9 +175,7 @@ def upgrade(ls, version, file, designation):
         wonderbits upgrade -f my_firmware.bin
 
         """
-    if ls:
-        wb_tool.upload.version_ls(hardware_str)
-    elif file:
+    if file:
         wb_tool.upload.update_bin(None, file)
     elif designation:
         MyUtil.wb_log(designation, version, '\r\n')
@@ -197,7 +195,9 @@ def upgrade(ls, version, file, designation):
             hardware_str = 'wonderbits'
         MyUtil.wb_log(hardware_str, '\n')
 
-        if version is None:
+        if ls:
+            wb_tool.upload.version_ls(hardware_str)
+        elif version is None:
             wb_tool.upload.update_bin(hardware_str)
         else:
             wb_tool.upload.update_bin(hardware_str, version)
